/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#include	"task.h"
#include	"stream.h"
#include	"change_endian.h"
#include	"machine/msequence.h"
#include	"init.h"
#include	"u_file.h"
#include	"utils.h"



int
main(int argc,char ** argv)
{
char * msg;
extern char * command_arg;
int ret;

	semlock_mode = SLM_REALTIME;
	set_fd_max(1024);
	command_arg = argv[0];
	check_endian();
	init_task(INI_DONTWAITCHI); 
	init_msequence();
	check_endian();
	init_tick();
	init_d_alloc();
	init_longchar();
	init_wct();
	init_stream();
	init_utils();
	init_netutils();
	init_resolve();

	if ( argc > 1 && argv[1][0] == '+' ) {
		msg = argv[1];
		argv[1] = argv[0];
		argv ++;
		argc --;
		proc_recv_stream(msg);
	}

	ret = call_main(argc,argv,_main);
	return ret;
}
